@@ -1,11 +1,17 @@
 
 /*
- *   Configuration for Linux 2.0.22 (untested)
+ *   Configuration for Linux 2.0.22
+ */
+
+/*
+ *   This should compile without problems. However I can't test it
+ *   since I don't have access to a Linux system with quota support.
+ *   If it doesn't work, uncomment #define NO_RPC below.
+ *   Mail me any results   -tom
  */
 
 #include <sys/param.h>
 #include <sys/types.h>
-/* #include <sys/quota.h>  /**/
 #include <linux/quota.h>
 #include <sys/syscall.h>
 #include <mntent.h>
@@ -13,6 +19,7 @@
 #include <rpc/rpc.h>
 #include <rpc/pmap_prot.h>
 #include <rpcsvc/rquota.h>
+/* #include "include/rquota.h" /**/
 #include <sys/socket.h>
 #include <netdb.h>
 
@@ -23,6 +30,9 @@
 #define Q_MUL * 2
 #define CADR (caddr_t)
 
+/* #define NO_RPC /**/
+#define MY_XDR
+
 #define MNTENT mntent
 
 #define GQR_STATUS status
