@@ -8,13 +8,19 @@
 /* This is needed for the quotactl syscall. See man quotactl(2) */
 #include <ufs/quota.h>
 
-/* This is needed for the mntent library routines. See man getmntent(3) */
+/* This is needed for the mntent library routines. See man getmntent(3)
+   another probable name is mnttab or mtab. Basically that's the name
+   of the file where mount(1m) keeps track of the current mounts.
+   See FILES section of man mount for the name of that file */
 #include <mntent.h>
 
-/* See man callrpc(3) and man rquota(3) */
+/* See includes list man callrpc(3) and man rquota(3) */
 #include <rpc/rpc.h>
 #include <rpc/pmap_prot.h>
-#include <rpcsvc/rquota.h>
+
+/* Select one of the following, preferring the first */
+#include <rpcsvc/rquota.h> /**/
+/* #include "include/rquota.h" /**/
 
 /* See man socket(2) and man gethostbyname(3) */
 #include <sys/socket.h>
@@ -32,18 +38,30 @@
    Do change only if your compiler complains */
 #define CADR (caddr_t)
 
-/* define if you don't want the rpcquery functionality */
-/* #define NO_RPC /* */
+/* define if you don't want the RPC query functionality,
+   i.e. you want to operate on the local host only */
+/* #define NO_RPC /**/
 
-/* define if you don't have a shared librpcsvc library
-   this includes the needed xdr routines from within this module */
-/* #define MY_RPC /* */
+/* This is for systems that lack librpcsvc and don't have xdr_getquota_args
+   et. al. in libc either. If you do have /usr/include/rpcsvc/rquota.x
+   you can generate these routines with rpcgen, too */
+/* #define MY_XDR /**/
+
+/* needed only if MOUNTED is not defined in <mnttab.h> (see above) */
+/* define MOUNTED mnttab /**/
 
 /* name of the structure used by getmntent(3) */
 #define MNTENT mntent
- 
+
+/* on some systems setmntent/endmntend do not exist  */
+/* #define NO_OPEN_MNTTAB /**/
+
+/* if your system doesn't have /etc/mnttab, and hence no getmntent,
+   use getmntinfo instead then (e.g. in OSF) */
+/* #define NO_MNTENT /**/
+
 /* name of the status entry in struc getquota_rslt and
-   name of the struc or union that contains the quota values.
+   name of the struct or union that contains the quota values.
    see include <rpcsvc/rquota.h> */
 #define GQR_STATUS gqr_status
 #define GQR_RQUOTA gqr_rquota
